package java.util.logging;

import java.util.Enumeration;
import java.util.ArrayList;
import java.util.List;

class Logging implements LoggingMXBean
{
    private static LogManager logManager;
    private static String EMPTY_STRING;
    
    Logging() {
    }
    
    @Override
    public List<String> getLoggerNames() {
        Enumeration<String> loggerNames = Logging.logManager.getLoggerNames();
        ArrayList<Object> list = new ArrayList();
        while (loggerNames.hasMoreElements()) {
            list.add(loggerNames.nextElement());
        }
        return list;
    }
    
    @Override
    public String getLoggerLevel(String s) {
        Logger logger = Logging.logManager.getLogger(s);
        if (logger == null) {
            return null;
        }
        Level level = logger.getLevel();
        if (level == null) {
            return Logging.EMPTY_STRING;
        }
        return level.getLevelName();
    }
    
    @Override
    public void setLoggerLevel(String str, String str2) {
        if (str == null) {
            throw new NullPointerException("loggerName is null");
        }
        Logger logger = Logging.logManager.getLogger(str);
        if (logger == null) {
            throw new IllegalArgumentException("Logger " + str + "does not exist");
        }
        Level level = null;
        if (str2 != null) {
            level = Level.findLevel(str2);
            if (level == null) {
                throw new IllegalArgumentException("Unknown level \"" + str2 + "\"");
            }
        }
        logger.setLevel(level);
        return;
    }
    
    @Override
    public String getParentLoggerName(String s) {
        Logger logger = Logging.logManager.getLogger(s);
        if (logger == null) {
            return null;
        }
        Logger parent = logger.getParent();
        if (parent == null) {
            return Logging.EMPTY_STRING;
        }
        return parent.getName();
    }
    
    static {
        Logging.logManager = LogManager.getLogManager();
        Logging.EMPTY_STRING = "";
    }
}
